require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xmaintenancewindow',
  dscmeta_resource_friendly_name: 'xMaintenanceWindow',
  dscmeta_resource_name: 'xMaintenanceWindow',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDscHelper',
  dscmeta_module_version: '1.0.41.1',
  docs: 'The DSC xMaintenanceWindow resource type.
         Automatically generated from version 1.0.41.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_currenttime: {
      type: 'Optional[Timestamp]',
      desc: 'Current system time',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DateTime',
      mof_is_embedded: false,
    },
    dsc_scheduleend: {
      type: 'Timestamp',
      desc: 'The end of the schedule. The property TimeOfDay is used for setting the schedule',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'DateTime',
      mof_is_embedded: false,
    },
    dsc_schedulestart: {
      type: 'Timestamp',
      desc: 'The start of the schedule. The property TimeOfDay is used for setting the schedule',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'DateTime',
      mof_is_embedded: false,
    },
    dsc_dayofweek: {
      type: "Optional[Enum['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday']]",
      desc: 'The day the maintenance window is defined for. ScheduleEnd can exceed the DayOfWeek',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scriptblock: {
      type: 'Optional[String]',
      desc: 'The script block to generate a schedule from an external system, e.g. a CMDB, a file, the moon phase, ... Needs to return a hash table with the keys ScheduleStart and ScheduleEnd. Can optionally contain all parameters of the DSC resource except ScriptBlock to further control resource processing. If ScriptBlock is used, all parameters are ignored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletype: {
      type: "Optional[Array[Enum['Once', 'Daily', 'Weekly', 'Monthly']]]",
      desc: 'The desired schedule. If the default Once is used, the exact date will be checked. If Daily is specified, DayOfWeek, DayOfMonth and DayNameOfMonth are ignored. If Weekly is specified, DayOfMonth is ignored. If Monthly is specified, DayOfWeek can be used to express nth Monday of the month',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_dayofmonth: {
      type: 'Optional[Integer[-32768, 32767]]',
      desc: 'The nth day of a month. In conjunction with DayOfWeek uses e.g. the nth Monday of the month',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt16',
      mof_is_embedded: false,
    },
  },
)
