require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xwaitforitem',
  dscmeta_resource_friendly_name: 'xWaitForItem',
  dscmeta_resource_name: 'xWaitForItem',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDscHelper',
  dscmeta_module_version: '1.0.41.1',
  docs: 'The DSC xWaitForItem resource type.
         Automatically generated from version 1.0.41.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_minimumchilditemcount: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The minimum child item count including all files and folders',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_type: {
      type: "Enum['Directory', 'File']",
      desc: 'The type of the target item',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Absent', 'Present']]",
      desc: 'Ensure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Retry count',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_retryinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Retry interval in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_childitemcount: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The exact child item count including all files and folders',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_minimumlength: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The minimum file length as implemented by System.IO.FileInfo',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'The path to the file or folder',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_length: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The exact file length as implemented by System.IO.FileInfo',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
  },
)
